local _, addon = ...

local frame = addon:CreateOptionsFrame("Book of Crafts")

frame:CreateOptions({
	{
		type = "CheckButton",
		text = "Only same faction",
		key = "sameFaction",
		func = "ClearCache",
	},
	{
		type = "CheckButton",
		text = "Use side tooltip",
		key = "separateTooltip",
	},
	{
		type = "CheckButton",
		text = "Colorize recipe items",
		key = "colorizeRecipes",
		func = "ClearCache",
	},
	{
		type = "ColorButton",
		text = "Usable",
		key = "usable",
		keyTable = "colors",
		func = "ClearCache",
	},
	{
		type = "ColorButton",
		text = "Insufficient skill",
		key = "lowSkill",
		keyTable = "colors",
		func = "ClearCache",
	},
	{
		type = "ColorButton",
		text = "Wrong spec",
		key = "noSpec",
		keyTable = "colors",
		func = "ClearCache",
	},
	{
		type = "ColorButton",
		text = "Already known",
		key = "knownBy",
		keyTable = "colors",
		func = "ClearCache",
	},
	{
		type = "ColorButton",
		text = "Unuseful recipe",
		key = "useless",
		keyTable = "colors",
		func = "ClearCache",
	},
})

function addon:LoadSettings()
	frame:SetDatabase(self.db.options)
	frame:SetHandler(self)
	frame:SetupControls()
end

SLASH_BOOKOFCRAFTS1 = "/boc"
SLASH_BOOKOFCRAFTS2 = "/bookofcrafts"
SlashCmdList.BOOKOFCRAFTS = function(cmd)
	InterfaceOptionsFrame_OpenToCategory(frame)
end


local function onClick(self)
	self.menu:Toggle()
	PlaySound("igMainMenuOptionCheckBoxOn")
end

local function createMenuButton()
	local button = addon:CreateButton(frame)
	button:SetWidth(128)
	button:SetScript("OnClick", onClick)
	button.arrow:Show()
	
	button.menu = addon:CreateDropdown("Menu")
	button.menu.relativeTo = button
	button.menu.relativePoint = "TOPRIGHT"
	
	return button
end

local popupData = {}

local function onClick(self, character, skill)
	popupData.character = character
	popupData.skill = skill
	StaticPopup_Show("BOOKOFCRAFTS_DELETE_DATA", addon.skills[skill] or "all", character, popupData)
	CloseDropDownMenus()
end

local charDropdown = createMenuButton()
charDropdown:SetPoint("TOPLEFT", frame.controls[#frame.controls], "BOTTOMLEFT", 0, -18)
charDropdown:SetText("Delete data")
charDropdown.menu.initialize = function(self, level)
	if level == 1 then
		for i, realm in ipairs(addon.menu.sortedRealms) do
			local info = UIDropDownMenu_CreateInfo()
			info.text = realm
			info.hasArrow = true
			info.notCheckable = true
			self:AddButton(info, level)
		end
	elseif level == 2 then
		local realm = UIDROPDOWNMENU_MENU_VALUE
		for i, characterKey in ipairs(addon.menu[realm].charNames) do
			local character, realm2 = characterKey:match("(.+) %- (.+)")
			if realm2 == realm then
				local info = UIDropDownMenu_CreateInfo()
				info.text = character
				info.value = characterKey
				if (characterKey ~= UnitName("player").." - "..GetRealmName()) then
					info.func = onClick
				end
				info.arg1 = characterKey
				info.hasArrow = (#addon.menu[realm].data[characterKey] > 0)
				info.notCheckable = true
				info.keepShownOnClick = (characterKey == UnitName("player").." - "..GetRealmName())
				self:AddButton(info, level)
			end
		end
	elseif level == 3 then
		local characterKey = UIDROPDOWNMENU_MENU_VALUE
		local realm = characterKey:match(".+ %- (.+)")
		for i, skill in ipairs(addon.menu[realm].data[characterKey]) do
			local info = UIDropDownMenu_CreateInfo()
			info.text = addon.skills[skill]
			info.func = onClick
			info.arg1 = characterKey
			info.arg2 = skill
			info.notCheckable = true
			self:AddButton(info, level)
		end
	end
end

do
	local function onAccept(self, data)
		addon:DeleteCharacterData(data.character, data.skill)
	end
	
	StaticPopupDialogs["BOOKOFCRAFTS_DELETE_DATA"] = {
		text = "Are you sure you want to delete %s data for %s?",
		button1 = YES,
		button2 = NO,
		OnAccept = onAccept,
		whileDead = true,
		timeout = 0,
	}
end

local function onClick(self, data, arg2, checked)
	data.ignore = checked or nil
	addon:ClearCache()
end

local ignoreMenu = createMenuButton()
ignoreMenu:SetPoint("TOP", charDropdown, "BOTTOM", 0, -8)
ignoreMenu:SetText("Ignore")
ignoreMenu.menu.initialize = function(self, level)
	if level == 1 then
		for i, realm in ipairs(addon.menu.sortedRealms) do
			local info = UIDropDownMenu_CreateInfo()
			info.text = realm
			info.hasArrow = true
			info.notCheckable = true
			self:AddButton(info, level)
		end
	elseif level == 2 then
		local realm = UIDROPDOWNMENU_MENU_VALUE
		local db = addon.db.skillData
		for i, characterKey in ipairs(addon.menu[realm].charNames) do
			local character, realm2 = characterKey:match("(.+) %- (.+)")
			if realm2 == realm then
				local info = UIDropDownMenu_CreateInfo()
				info.text = character
				info.value = characterKey
				info.func = onClick
				info.arg1 = db[characterKey]
				info.hasArrow = (#addon.menu[realm].data[characterKey] > 0)
				info.checked = db[characterKey].ignore
				info.isNotRadio = true
				info.keepShownOnClick = true
				self:AddButton(info, level)
			end
		end
	elseif level == 3 then
		local characterKey = UIDROPDOWNMENU_MENU_VALUE
		local realm = characterKey:match(".+ %- (.+)")
		local db = addon.db.skillData[characterKey].skills
		for i, skill in ipairs(addon.menu[realm].data[characterKey]) do
			local info = UIDropDownMenu_CreateInfo()
			info.text = addon.skills[skill]
			info.func = onClick
			info.arg1 = db[skill]
			info.checked = db[skill].ignore
			info.isNotRadio = true
			info.keepShownOnClick = true
			self:AddButton(info, level)
		end
	end
end